"""
使用该cookies，可以获取页面的`_SSR_HYDRATED_DATA`

参考：https://github.com/soimort/you-get/blob/29f513821df4b0ec3ed0b514a0897f8c336b51e7/src/you_get/extractors/ixigua.py
"""

cookies = {
    'MONITOR_WEB_ID': '7892c49b-296e-4499-8704-e47c1b15123',
    '__ac_nonce': '060d88ff000a75e8d17eb',
    '__ac_signature': '_02B4Z6wo100f01kX9ZpgAAIDAKIBBQUIPYT5F2WIAAPG2ad',
    'ttwid': '1%7CcIsVF_3vqSIk4XErhPB0H2VaTxT0tdsTMRbMjrJOPN8%7C1624806049%7C08ce7dd6f7d20506a41ba0a331ef96a6505d96731e6ad9f6c8c709f53f227ab1'
}
